#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <utime.h>
#include <unistd.h>

/*
 * Funkcija error_fatal() ispisuje dati string, a onda i poruku o sistemskoj
 * greski i potom prekida program.
 */
static void     error_fatal(char *message);

/*
 * Program demonstrira utime() sistemski poziv. Program brise sadrzaj fajlova
 * cija su imena navedena u komandnoj liniji, a zatim vraca vremena zadnjeg
 * pristupa i modifikacije na one vrednosti koje su bile postavljene pre
 * gornje operacije.
 */
int main(int argc, char **argv){
  struct stat     stats;
  struct utimbuf  times;
  int             i, fd;
  
  /* U petlji se za svaki fajl naveden u komandnoj liniji... */
  for (i = 1; i < argc; i++) {
    /* ...ocitavaju vremena zadnjeg pristupa i modifikacije,... */
    if (stat(argv[i], &stats) < 0)
      error_fatal("stat error");
    
    /* ...zatim se brise sadrzaj fajla... */
    if ( (fd = open(argv[i], O_RDWR | O_TRUNC)) < 0)
      error_fatal("open error");
    
    close (fd);
    /*
     * ...i onda se vracaju vremena zadnjeg pristupa i
     * modifikacije na zapamcene vredosti.
     * PAZNJA: Koristi se funkcija utime, a ne utimes.
     */
    times.actime = stats.st_atime;
    times.modtime = stats.st_mtime;
    if (utime(argv[i], &times) < 0)
      error_fatal("utime error");
  }
  
  /* Zavrsava se program. */
  exit(EXIT_SUCCESS);
}

static void error_fatal(char *message){
  /* Stampa se poruka o greski. */
  perror(message);
  
  /* Prekida se program. */
  exit(EXIT_FAILURE);
}
